@@ -4,7 +4,7 @@
 * acp_board [Português]
 *
 * @package language
-* @version 1.0.0
+* @version 1.0.2
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -45,7 +45,7 @@ $lang = array_merge($lang, array(
 	'DEFAULT_LANGUAGE'				=> 'Idioma Padrão',
 	'DEFAULT_STYLE'					=> 'Estilo Padrão',
 	'DISABLE_BOARD'					=> 'Desativar o Fórum',
-	'DISABLE_BOARD_EXPLAIN'			=> 'O Fórum fica inacessível aos Utilizadores. Pode justificar o fecho temporário introduzindo uma Mensagem até 255 carateres',
+	'DISABLE_BOARD_EXPLAIN'			=> 'O Fórum fica inacessível aos Utilizadores. Pode justificar o fecho temporário introduzindo uma Mensagem até 255 caracteres',
 	'OVERRIDE_STYLE'				=> 'Sobrepor Estilo do Utilizador',
 	'OVERRIDE_STYLE_EXPLAIN'		=> 'Substitui o Estilo do Utilizador pelo Estilo Padrão do Fórum.',
 	'SITE_DESC'						=> 'Descrição do Site',
@@ -54,7 +54,7 @@ $lang = array_merge($lang, array(
     'SYSTEM_TIMEZONE'				=> 'Fuso horário do visitante',
     'SYSTEM_TIMEZONE_EXPLAIN'		=> 'Fuso horário a mostrar a utilizadores não ligados (visitantes, motores de busca). Os utilizadores ligados definem o seu fuso horário durante o registo e podem alterá-lo no Painel de Controlo do Utilizador.',
 	'WARNINGS_EXPIRE'				=> 'Duração do aviso',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'O número de dias que uma advertência permanece no Registo do Utilizador.',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'O número de dias que uma advertência permanece no Registo do Utilizador. Defina como 0 para advertência permanente.',
 )); 
 
 // Board Features 
@@ -138,7 +138,7 @@ $lang = array_merge($lang, array(
 	'FULL_FOLDER_ACTION_EXPLAIN'	=> 'Define o procedimento se a pasta do Utilizador encher e a ação configurada não for aplicável. Na pasta "Mensagens enviadas" serão sempre excluídas as Mensagens mais antigas.',
 	'HOLD_NEW_MESSAGES'				=> 'Manuseio de novas Mensagens',
 	'PM_EDIT_TIME'					=> 'Limite do tempo de edição',
-	'PM_EDIT_TIME_EXPLAIN'			=> 'Limita o tempo para editar uma Mensagem Privada ainda não enviada (0 = ilimitado).',
+	'PM_EDIT_TIME_EXPLAIN'			=> 'Limita o tempo disponível para editar uma nova Mensagem Privada ainda não enviada (0 = ilimitado).',
 	'PM_MAX_RECIPIENTS'				=> 'Número máximo de destinatários',
 	'PM_MAX_RECIPIENTS_EXPLAIN'		=> 'Número máximo de destinatários por Mensagem Privada (0 = ilimitado). Estes valores podem ser ajustados por Grupo nas configurações do Grupo.',
 )); 
@@ -153,15 +153,15 @@ $lang = array_merge($lang, array(
 
 	'BUMP_INTERVAL'					=> 'Intervalo de Bump',
 	'BUMP_INTERVAL_EXPLAIN'			=> 'Número de minutos, horas ou dias entre a última Mensagem num Tópico e a reativação deste Tópico. Definir o valor como 0 desativa este recurso.',
-	'CHAR_LIMIT'					=> 'Máximo de carateres por Mensagem',
-	'CHAR_LIMIT_EXPLAIN'			=> 'Número máximo de carateres da mensagem. 0 = Ilimitados.',
+	'CHAR_LIMIT'					=> 'Máximo de caracteres por Mensagem',
+	'CHAR_LIMIT_EXPLAIN'			=> 'Número máximo de caracteres da mensagem. 0 = Ilimitados.',
 	'DELETE_TIME'					=> 'Tempo limite para apagar',
-	'DELETE_TIME_EXPLAIN'			=> 'Limita o tempo disponível para eliminar uma nova mensagem. Definir o valor como 0 desativa esta função.',
+	'DELETE_TIME_EXPLAIN'			=> 'Limita o tempo disponível para eliminar uma nova Mensagem (0 = ilimitado).',
 	'DISPLAY_LAST_EDITED'			=> 'Mostra a data e a hora da última edição',
 	'DISPLAY_LAST_EDITED_EXPLAIN'	=> 'Se ativo mostra a data e a hora da última edição da Mensagem.',
 	'EDIT_TIME'						=> 'Tempo limite de edição',
-	'EDIT_TIME_EXPLAIN'				=> 'Limita o tempo disponível para se editar uma nova Mensagem 0 = ilimitado).',
-	'FLOOD_INTERVAL'				=> 'Intervalo de Fluxo',
+	'EDIT_TIME_EXPLAIN'				=> 'Limita o tempo disponível para editar uma nova Mensagem (0 = ilimitado).',
+	'FLOOD_INTERVAL'				=> 'Intervalo de Segurança.',
 	'FLOOD_INTERVAL_EXPLAIN'		=> 'Número de segundos que o Utilizador tem de esperar para criar nova Mensagem.',
 	'HOT_THRESHOLD'					=> 'Mensagens para se tornar um Tópico Popular',
 	'HOT_THRESHOLD_EXPLAIN'			=> 'Número de Mensagens para tornar um Tópico Popular. <strong>0 para desativar</strong>',
@@ -174,8 +174,8 @@ $lang = array_merge($lang, array(
 	'MAX_POST_IMG_WIDTH_EXPLAIN'	=> 'Largura máxima das imagens/flash nas Mensagens 0 = ilimitado.',
 	'MAX_POST_URLS'					=> 'Número máximo de URLs por Mensagem',
 	'MAX_POST_URLS_EXPLAIN'			=> 'Número máximo de URLs que podem ser inseridas numa mensagem. 0 = Ilimitadas.',
-	'MIN_CHAR_LIMIT'				=> 'Mínimo de carateres por Mensagem',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'O número mínimo de carateres que o Utilizador tem de usar numa Mensagem.',
+	'MIN_CHAR_LIMIT'				=> 'Mínimo de caracteres por Mensagem',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'O número mínimo de caracteres que o Utilizador tem de usar numa Mensagem. 1 é o valor mínimo admitido nesta configuração.',
 	'POSTING'						=> 'Postando',
 	'POSTS_PER_PAGE'				=> 'Mensagens por página',
 	'QUOTE_DEPTH_LIMIT'				=> 'Tamanho máximo das citações',
@@ -197,7 +197,7 @@ $lang = array_merge($lang, array(
 	'MAX_SIG_IMG_WIDTH'					=> 'Largura Máxima de uma imagem na Assinatura',
 	'MAX_SIG_IMG_WIDTH_EXPLAIN'			=> 'Largura Máxima de um ficheiro de imagem/flash na Assinatura do Utilizador. (0 = Ilimitado).',
 	'MAX_SIG_LENGTH'					=> 'Comprimento máximo da Assinatura',
-	'MAX_SIG_LENGTH_EXPLAIN'			=> 'Número Máximo de carateres na Assinatura do Utilizador.',
+	'MAX_SIG_LENGTH_EXPLAIN'			=> 'Número Máximo de caracteres na Assinatura do Utilizador.',
 	'MAX_SIG_SMILIES'					=> 'Número Máximo de Emoções por Assinatura',
 	'MAX_SIG_SMILIES_EXPLAIN'			=> 'Número Máximo de Emoções permitidas na Assinatura do Utilizador. (0 = Ilimitado).',
 	'MAX_SIG_URLS'						=> 'Número Máximo de atalhos',
@@ -232,7 +232,7 @@ $lang = array_merge($lang, array(
 	'MIN_CHARS'							=> 'Mínimo',
 	'NO_AUTH_PLUGIN'					=> 'Nenhum Módulo de Segurança encontrado.',
 	'PASSWORD_LENGTH'					=> 'Tamanho da Senha',
-	'PASSWORD_LENGTH_EXPLAIN'			=> 'Número Mínimo e Máximo de carateres das Senhas.',
+	'PASSWORD_LENGTH_EXPLAIN'			=> 'Número Mínimo e Máximo de caracteres das Senhas.',
 	'REG_LIMIT'							=> 'Tentativas de Registo',
 	'REG_LIMIT_EXPLAIN'         		=> 'Número de tentativas permitidas aos utilizadores antes da sessão ser bloqueada.',
 	'USERNAME_ALPHA_ONLY'				=> 'Alfanumérico apenas',
@@ -240,11 +240,11 @@ $lang = array_merge($lang, array(
 	'USERNAME_ASCII'					=> 'ASCII (Nenhum padrão de codificação unicode internacional)',
 	'USERNAME_LETTER_NUM'				=> 'Qualquer letra ou número',
 	'USERNAME_LETTER_NUM_SPACERS'		=> 'Qualquer letra, número, ou espaço',
-	'USERNAME_CHARS'					=> 'Limite de carateres para o nome do Utilizador',
-	'USERNAME_CHARS_ANY'				=> 'Qualquer carater',
-	'USERNAME_CHARS_EXPLAIN'			=> 'Tipo restrito de carateres aceites no nome do Utilizador; espaço, -, +, _, [ e ].',
+	'USERNAME_CHARS'					=> 'Limite de caracteres para o nome do Utilizador',
+	'USERNAME_CHARS_ANY'				=> 'Qualquer caractere',
+	'USERNAME_CHARS_EXPLAIN'			=> 'Tipo restrito de caracteres aceites no nome do Utilizador; espaço, -, +, _, [ e ].',
 	'USERNAME_LENGTH'					=> 'Tamanho do nome do Utilizador',
-	'USERNAME_LENGTH_EXPLAIN'			=> 'Número Mínimo e Máximo de carateres nos nomes dos Utilizadors.',
+	'USERNAME_LENGTH_EXPLAIN'			=> 'Número Mínimo e Máximo de caracteres nos nomes dos Utilizadors.',
 )); 
 
 // Feeds
