@@ -4,7 +4,7 @@
 * acp_common [Português]
 *
 * @package language
-* @version 1.0.0
+* @version 1.0.2
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -317,7 +317,7 @@ $lang = array_merge($lang, array(
 
 // Index page 
 $lang = array_merge($lang, array( 
-	'ADMIN_INTRO'					=> 'Obrigado por usar o <b>phpBB3</b> no seu Fórum. Esta página apresenta as Estatísticas Gerais do Fórum.<br /> À esquerda encontra os Menus de acesso ao <b>Painel de Administração</b>. Cada um deles contém instruções de configuração.',
+	'ADMIN_INTRO'					=> 'Obrigado por usar o <b>phpBB3</b> no seu Fórum. Esta página apresenta as Estatísticas Gerais do Fórum.<br /> À esquerda encontra os menus de acesso ao <b>Painel de Administração</b>. Cada um deles contém instruções de configuração.',
 	'ADMIN_LOG'						=> 'Registos da ações dos Administradores',
 	'ADMIN_LOG_INDEX_EXPLAIN'		=> 'Este registo mostra as últimas cinco ações dos Administradores.<br />Uma cópia completa do registo está disponível no item apropriado do Menu ou seguindo o atalho abaixo.',
 	'AVATAR_DIR_SIZE'				=> 'Tamanho da diretoria dos avatares',
@@ -328,6 +328,16 @@ $lang = array_merge($lang, array(
 	'DATABASE_SERVER_INFO'			=> 'Servidor da Base de Dados',
 	'DATABASE_SIZE'					=> 'Tamanho da Base de Dados',
 
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'A função de sobrecarga está configurada incorretamente',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> deve ser definido para 0 ou 4. Pode verificar o valor atual em <samp>informação PHP</samp> page.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'Transparent character encoding is improperly configured',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> must be set to 0. Pode verificar o valor atual em <samp>informação PHP</samp> page.',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'HTTP input character conversion is improperly configured',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> must be set to <samp>pass</samp>. Pode verificar o valor atual em the <samp>informação PHP</samp> page.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'HTTP output character conversion is improperly configured',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> must be set to <samp>pass</samp>. Pode verificar o valor atual em <samp>informação PHP</samp> page.',
+
 	'FILES_PER_DAY'					=> 'Média de Anexos diários',
 	'FORUM_STATS'					=> 'Estatísticas do Fórum',
 
