@@ -4,7 +4,7 @@
 * acp_permissions [Português]
 *
 * @package language
-* @version 1.0.0
+* @version 1.0.2
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -211,7 +211,7 @@ $lang = array_merge($lang, array(
 	'ROLE_DESCRIPTION_USER_NEW_MEMBER'		=> 'A função dos membros do Grupo Especial de Utilizadores Registados Recentemente. Contém permissões <b>Nunca</b> para bloquear recursos aos novos utilizadores.',
 
 	'ROLE_DESCRIPTION_EXPLAIN'				=> 'Pode escrever uma pequena explicação sobre a tarefa o objetivo da mesma. O Texto será mostrado nas Permissões.',
-	'ROLE_DESCRIPTION_LONG'					=> 'A Descrição da tarefa é muito grande. Por Favor, limite seu texto a 4000 carateres.',
+	'ROLE_DESCRIPTION_LONG'					=> 'A Descrição da tarefa é muito grande. Por Favor, limite seu texto a 4000 caracteres.',
 	'ROLE_DETAILS'							=> 'Detalhes da tarefa',
 	'ROLE_EDIT_SUCCESS'						=> 'A Tarefa foi editada com sucesso.',
 	'ROLE_NAME'								=> 'Nome da Tarefa',
