@@ -4,7 +4,7 @@
 * acp_styles [Português]
 *
 * @package language
-* @version 1.0.0
+* @version 1.0.2
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -130,10 +130,10 @@ $lang = array_merge($lang, array(
 	'IMAGESET_DELETED_FS'			=> 'Conjunto de Imagens removido da Base de Dados mas alguns ficheiros ainda restam no Sistema de Ficheiros.',
 	'IMAGESET_DETAILS_UPDATED'		=> 'Detalhes do Conjunto de Imagens atualizado com sucesso.',
 	'IMAGESET_ERR_ARCHIVE'			=> 'Por favor selecione um método de Ficheiro.',
-	'IMAGESET_ERR_COPY_LONG'		=> 'O copyright não pode ter mais que 60 carateres.',
-	'IMAGESET_ERR_NAME_CHARS'		=> 'O nome do conjunto de Imagens pode conter apenas carateres alfanuméricos, -, +, _ e espaço.',
+	'IMAGESET_ERR_COPY_LONG'		=> 'O copyright não pode ter mais que 60 caracteres.',
+	'IMAGESET_ERR_NAME_CHARS'		=> 'O nome do conjunto de Imagens pode conter apenas caracteres alfanuméricos, -, +, _ e espaço.',
 	'IMAGESET_ERR_NAME_EXIST'		=> 'Um conjunto de Imagens com o mesmo nome já existe.',
-	'IMAGESET_ERR_NAME_LONG'		=> 'O nome do conjunto de Imagens não pode conter mais que 30 carateres.',
+	'IMAGESET_ERR_NAME_LONG'		=> 'O nome do conjunto de Imagens não pode conter mais que 30 caracteres.',
 	'IMAGESET_ERR_NOT_IMAGESET'		=> 'O Ficheiro que especificou não contém um Conjunto de Imagens válido.',
 	'IMAGESET_ERR_STYLE_NAME'		=> 'Tem que indicar um nome para este Conjunto de Imagens.',
 	'IMAGESET_EXPORT'				=> 'Exportar Conjunto de Imagens',
@@ -350,13 +350,13 @@ $lang = array_merge($lang, array(
 	'STYLE_DELETED'					=> 'Estilo apagado com sucesso.',
 	'STYLE_DETAILS_UPDATED'			=> 'Estilo editado com sucesso.',
 	'STYLE_ERR_ARCHIVE'				=> 'Por favor selecione um método de Ficheiro.',
-	'STYLE_ERR_COPY_LONG'			=> 'O copyright não pode ter mais que 60 carateres.',
+	'STYLE_ERR_COPY_LONG'			=> 'O copyright não pode ter mais que 60 caracteres.',
 	'STYLE_ERR_MORE_ELEMENTS'		=> 'Deve selecionar pelo menos um Estilo.',
-	'STYLE_ERR_NAME_CHARS'			=> 'O nome do Estilo pode conter apenas carateres alfanuméricos, -, +, _ e espaço.',
+	'STYLE_ERR_NAME_CHARS'			=> 'O nome do Estilo pode conter apenas caracteres alfanuméricos, -, +, _ e espaço.',
 	'STYLE_ERR_NAME_EXIST'			=> 'Um Estilo com o mesmo nome já existe.',
-	'STYLE_ERR_NAME_LONG'			=> 'O nome do Estilo não pode ter mais que 30 carateres.',
+	'STYLE_ERR_NAME_LONG'			=> 'O nome do Estilo não pode ter mais que 30 caracteres.',
 	'STYLE_ERR_NO_IDS'				=> 'Tem que selecionar um template, Tema e Conjunto de imagens para este Estilo.',
-	'STYLE_ERR_NOT_STYLE'			=> 'O Ficheiro importado ou enviado não contém um Ficheiro válido de Estilo.',
+	'STYLE_ERR_NOT_STYLE'			=> 'O ficheiro importado ou enviado não contém um ficheiro válido de Estilo.',
 	'STYLE_ERR_STYLE_NAME'			=> 'Tem que especificar um nome para este Estilo.',
 	'STYLE_EXPORT'					=> 'Exportar Estilo',
 	'STYLE_EXPORT_EXPLAIN'			=> 'Aqui pode exportar um Estilo no Formulário de Ficheiro. Um Estilo não precisa conter todos os elementos mas deve conter pelo menos um. Por exemplo, se tivesse criado um novo Tema e Conjunto de Imagens para um Template, pode exportar o Tema e o Conjunto de Imagens e omitir o Template. Deve selecionar entre transferir o Ficheiro diretamente ou enviá-lo para a sua pasta de arquivo para transferir depois por FTP.',
@@ -381,10 +381,10 @@ $lang = array_merge($lang, array(
 	'TEMPLATE_EDITOR_HEIGHT'		=> 'Altura do editor de Template',
 	'TEMPLATE_ERR_ARCHIVE'			=> 'Por favor selecione um método de Ficheiro.',
 	'TEMPLATE_ERR_CACHE_READ'		=> 'A diretoria de cache usada para armazenar as versões em cache dos Ficheiros de Template não pode ser aberta.',
-	'TEMPLATE_ERR_COPY_LONG'		=> 'O copyright não pode ter mais que 60 carateres.',
-	'TEMPLATE_ERR_NAME_CHARS'		=> 'O nome do Template pode conter apenas carateres alfanuméricos, -, +, _ e espaço.',
+	'TEMPLATE_ERR_COPY_LONG'		=> 'O copyright não pode ter mais que 60 caracteres.',
+	'TEMPLATE_ERR_NAME_CHARS'		=> 'O nome do Template pode conter apenas caracteres alfanuméricos, -, +, _ e espaço.',
 	'TEMPLATE_ERR_NAME_EXIST'		=> 'Já existe um Conjunto de Template com o mesmo nome.',
-	'TEMPLATE_ERR_NAME_LONG'		=> 'O nome do Template não pode ter mais que 30 carateres.',
+	'TEMPLATE_ERR_NAME_LONG'		=> 'O nome do Template não pode ter mais que 30 caracteres.',
 	'TEMPLATE_ERR_NOT_TEMPLATE'		=> 'O Ficheiro especificado não contém um Conjunto de Template válido.',
 	'TEMPLATE_ERR_REQUIRED_OR_INCOMPLETE' => 'O novo Template escolhido requer o Template %s para ser instalado e não herdando de si mesmo.',
 	'TEMPLATE_ERR_STYLE_NAME'		=> 'Tem que especificar um nome válido para este template.',
@@ -409,11 +409,11 @@ $lang = array_merge($lang, array(
 	'THEME_EDITOR'					=> 'Editor de Tema',
 	'THEME_EDITOR_HEIGHT'			=> 'Altura do editor de Tema',
 	'THEME_ERR_ARCHIVE'				=> 'Por favor selecione um método de Ficheiro.',
-	'THEME_ERR_CLASS_CHARS'			=> 'Apenas carateres alfanuméricos e ., :, -, _ e # são validos em nomes de classes.',
-	'THEME_ERR_COPY_LONG'			=> 'O copyright não pode ter mais que 60 carateres.',
-	'THEME_ERR_NAME_CHARS'			=> 'O nome do Tema pode conter apenas carateres alfanuméricos, -, +, _ e espaço.',
+	'THEME_ERR_CLASS_CHARS'			=> 'Apenas caracteres alfanuméricos e ., :, -, _ e # são validos em nomes de classes.',
+	'THEME_ERR_COPY_LONG'			=> 'O copyright não pode ter mais que 60 caracteres.',
+	'THEME_ERR_NAME_CHARS'			=> 'O nome do Tema pode conter apenas caracteres alfanuméricos, -, +, _ e espaço.',
 	'THEME_ERR_NAME_EXIST'			=> 'Já existe um Tema com o mesmo nome.',
-	'THEME_ERR_NAME_LONG'			=> 'O nome do Tema não pode ter mais do que 30 carateres.',
+	'THEME_ERR_NAME_LONG'			=> 'O nome do Tema não pode ter mais do que 30 caracteres.',
 	'THEME_ERR_NOT_THEME'			=> 'O Ficheiro que especificou não contém um Tema válido.',
 	'THEME_ERR_REFRESH_FS'			=> 'Este Tema está armazenado no Sistema de Ficheiros e não há necessidade de atualizá-lo.',
 	'THEME_ERR_STYLE_NAME'			=> 'Tem que fornecer um nome para este tema.',
