@@ -4,7 +4,7 @@
 * common [Português]
 *
 * @package language
-* @version 1.0.0
+* @version 1.0.2
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -41,7 +41,7 @@ if (empty($lang) || !is_array($lang))
 //
 
 $lang = array_merge($lang, array(
-	'TRANSLATION_INFO'					=> 'Traduzido por <a href="http://phpbbportugal.com" target="_blank" title="phpBB Portugal"><b>phpBB Portugal</b></a>',
+	'TRANSLATION_INFO'					=> 'Traduzido por <a href="http://phpbbportugal.com" title="phpBB Portugal"><b>phpBB Portugal</b></a>',
 	'DIRECTION'							=> 'ltr',
 	'DATE_FORMAT'						=> '|d M Y|',	// 01 Jan 2007 (with Relative days enabled) 
 	'USER_LANG'							=> 'pt',
@@ -166,6 +166,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Precisa especificar um assunto quando escrever uma nova mensagem.',
 	'ENABLED'							=> 'Ativado',
 	'ENCLOSURE'							=> 'Documento anexo',
+	'ENTER_USERNAME'					=> 'Introduza o Utilizador',
 	'ERR_CHANGING_DIRECTORY'			=> 'Não foi possível alterar a diretoria.',
 	'ERR_CONNECTING_SERVER'				=> 'Erro ao ligar-se ao servidor.',
 	'ERR_JAB_AUTH'						=> 'Não foi autorizado a entrar no servidor Jabber.',
@@ -201,6 +202,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'					=> 'Por Favor, clique aqui para ver as regras do Fórum',
 	'FROM'								=> 'de',
 	'FSOCK_DISABLED'					=> 'Não foi possível concluir esta operação, porque a função <var>fsockopen</var> está desativada ou o servidor solicitado não foi encontrado.',
+	'FSOCK_TIMEOUT'						=> 'O tempo limite esgotou-se durante a leitura do fluxo de rede',
 
 	'FTP_FSOCK_HOST'					=> 'Servidor FTP',
 	'FTP_FSOCK_HOST_EXPLAIN'			=> 'Servidor FTP utilizada para se ligar ao seu site.',
@@ -652,9 +654,13 @@ $lang = array_merge($lang, array(
 	'UNREAD_PM'							=> '<b>%d</b> mensagem não lida',
 	'UNREAD_PMS'						=> '<b>%d</b> mensagens não lidas',
 	'UNREAD_POST'						=> 'Mensagem não lida',
-	'UNREAD_POSTS'						=> 'Mensagens não lidas',	
-	'UNWATCHED_FORUMS'					=> 'Já não se encontra a observar  este Fórum.',
-	'UNWATCHED_TOPICS'					=> 'Já não se encontra a observar  este Tópico.',
+	'UNREAD_POSTS'						=> 'Mensagens não lidas',
+	'UNWATCH_FORUM_CONFIRM'				=> 'Tem certeza que deseja cancelar a assinatura deste forum?',
+	'UNWATCH_FORUM_DETAILED'			=> 'Tem certeza que deseja cancelar a assinatura do forum “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'				=> 'Tem certeza que deseja cancelar a assinatura deste Topico?',
+	'UNWATCH_TOPIC_DETAILED'			=> 'Tem certeza que deseja cancelar a assinatura do Topico “%s”?',
+	'UNWATCHED_FORUMS'					=> 'Já não se encontra a observar este Fórum.',
+	'UNWATCHED_TOPICS'					=> 'Já não se encontra a observar este Tópico.',
 	'UNWATCHED_FORUMS_TOPICS'			=> 'Já não se encontra a observar as entradas selecionadas.',
 	'UPDATE'							=> 'Atualizar',
 	'UPLOAD_IN_PROGRESS'				=> 'O envio está em progresso.',
@@ -701,6 +707,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'							=> 'Avisos',
 	'WARN_USER'							=> 'Avisar Utilizador',
+	'WATCH_FORUM_CONFIRM'				=> 'Tem certeza que deseja subscrever este Fórum?',
+	'WATCH_FORUM_DETAILED'				=> 'Tem certeza que deseja subscrever o Fórum “%s”?',
+	'WATCH_TOPIC_CONFIRM'				=> 'Tem certeza que deseja subscrever este Tópico?',
+	'WATCH_TOPIC_DETAILED'				=> 'Tem certeza que deseja subscrever o Tópico “%s”?',
 	'WELCOME_SUBJECT'					=> 'Bem vindo ao Fórum',
 	'WEBSITE'							=> 'Sítio web',
 	'WHOIS'								=> 'Quem',
