@@ -4,7 +4,7 @@
 * ucp [Português]
 *
 * @package language
-* @version 1.0.0
+* @version 1.0.2
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -176,6 +176,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'						=> 'Imagem Atual',
 	'CURRENT_PASSWORD'					=> 'Senha Atual',
 	'CURRENT_PASSWORD_EXPLAIN'			=> 'Introduza a Senha atual para validar as alterações.',
+	'CUR_PASSWORD_EMPTY'				=> 'Não digitou a senha atual.',
 	'CUR_PASSWORD_ERROR'				=> 'A Senha atual que escreveu está incorreta.',
 	'CUSTOM_DATEFORMAT'					=> 'Personalizar',
 
@@ -225,13 +226,13 @@ $lang = array_merge($lang, array(
 	'EXPORT_FOLDER'						=> 'Exportar Pasta',
 
 	'FIELD_REQUIRED'					=> 'O Campo "% s" deve ser preenchido.',
-	'FIELD_TOO_SHORT'					=> 'O Campo "%1$s" é muito curto. O mínimo de carateres é de %2$d.',
-	'FIELD_TOO_LONG'					=> 'O Campo "%1$s" é muito longo. O máximo de carateres permitidos são %2$d.',
+	'FIELD_TOO_SHORT'					=> 'O Campo "%1$s" é muito curto. O mínimo de caracteres é de %2$d.',
+	'FIELD_TOO_LONG'					=> 'O Campo "%1$s" é muito longo. O máximo de caratceres permitidos são %2$d.',
 	'FIELD_TOO_SMALL'					=> 'O Valor de "%1$s" é muito pequeno. O valor mínimo é de %2$d.',
 	'FIELD_TOO_LARGE'					=> 'O Valor de "%1$s" é muito grande. O valor máximo é de %2$d.',
-	'FIELD_INVALID_CHARS_NUMBERS_ONLY'	=> 'O Campo "% s" tem carateres inválidos. São permitidos somente números.',
-	'FIELD_INVALID_CHARS_ALPHA_ONLY'	=> 'O Campo "% s" tem carateres inválidos. São permitidos somente carateres alfanuméricos.',
-	'FIELD_INVALID_CHARS_SPACERS_ONLY'	=> 'O Campo "% s" tem carateres inválidos. Somente alfanumérico, espaço ou - +_ [] são permitidos.',
+	'FIELD_INVALID_CHARS_NUMBERS_ONLY'	=> 'O Campo "% s" tem caracteres inválidos. São permitidos somente números.',
+	'FIELD_INVALID_CHARS_ALPHA_ONLY'	=> 'O Campo "% s" tem caracteres inválidos. São permitidos somente caracteres alfanuméricos.',
+	'FIELD_INVALID_CHARS_SPACERS_ONLY'	=> 'O Campo "% s" tem caracteres inválidos. Somente alfanumérico, espaço ou - +_ [] são permitidos.',
 	'FIELD_INVALID_DATE'				=> 'O Campo "% s" tem uma data inválida.',
 	'FIELD_INVALID_VALUE'				=> 'O Campo “%s” um valor inválido.',
 
@@ -271,8 +272,8 @@ $lang = array_merge($lang, array(
 	'IF_FOLDER_FULL'					=> 'Se a Pasta estiver cheia',
 	'IMPORTANT_NEWS'					=> 'Anúncios Importantes',
 	'INVALID_USER_BIRTHDAY'				=> 'A data de nascimento não é válida.',
-	'INVALID_CHARS_USERNAME'			=> 'O Nome de utilizador contém carateres proibidos.',
-	'INVALID_CHARS_NEW_PASSWORD'		=> 'A Senha não tem os carateres exigidos.',
+	'INVALID_CHARS_USERNAME'			=> 'O Nome de utilizador contém caracteres proibidos.',
+	'INVALID_CHARS_NEW_PASSWORD'		=> 'A Senha não caracteres exigidos.',
 	'ITEMS_REQUIRED'					=> 'Os itens marcados com * são campos de preenchimento obrigatório.',
 
 	'JOIN_SELECTED'						=> 'Aderir ao selecionado',
@@ -306,9 +307,11 @@ $lang = array_merge($lang, array(
 	'MOVE_TO_FOLDER'					=> 'Mover para a Pasta',
 	'MOVE_UP'							=> 'Mover - Cima',
 
+	'NEW_EMAIL_CONFIRM_EMPTY'			=> 'Não digitou o email de confirmação.',
 	'NEW_EMAIL_ERROR'					=> 'Os endereços de email indicados são diferentes.',
 	'NEW_FOLDER_NAME'					=> 'Nome da nova Pasta',
-	'NEW_PASSWORD'						=> 'Senha',
+	'NEW_PASSWORD'						=> 'Nova Senha',
+	'NEW_PASSWORD_CONFIRM_EMPTY'		=> 'Não digitou a Senha de confirmação.',
 	'NEW_PASSWORD_ERROR'				=> 'As Senhas indicadas são diferentes.',
 	'NOTIFY_METHOD'						=> 'Método de Aviso',
 	'NOTIFY_METHOD_BOTH'				=> 'Ambos',
@@ -368,10 +371,10 @@ $lang = array_merge($lang, array(
 	'NO_WATCHED_SELECTED'				=> 'Não selecionou nenhum Tópico ou Fórum Observado.',	
 	'NO_WATCHED_TOPICS'					=> 'Não está a observar nenhum Tópico.',
 
-	'PASS_TYPE_ALPHA_EXPLAIN'			=> 'Deve ter entre %1$d e %2$d carateres alfanuméricos.',
-	'PASS_TYPE_ANY_EXPLAIN'				=> 'Deve ter entre %1$d e %2$d carateres.',
-	'PASS_TYPE_CASE_EXPLAIN'			=> 'Deve ter entre %1$d e %2$d carateres e deve conter casos misturados.',
-	'PASS_TYPE_SYMBOL_EXPLAIN'			=> 'Deve ter entre %1$d e %2$d carateres e deve conter símbolos.',
+	'PASS_TYPE_ALPHA_EXPLAIN'			=> 'Deve ter entre %1$d e %2$d caracteres. Tem que incluir letras maiúsculas e minúsculas e números.',
+	'PASS_TYPE_ANY_EXPLAIN'				=> 'Deve ter entre %1$d e %2$d caracteres.',
+	'PASS_TYPE_CASE_EXPLAIN'			=> 'Deve ter entre %1$d e %2$d caracteres. Tem que incluir letras maiúsculas e minúsculas.',
+	'PASS_TYPE_SYMBOL_EXPLAIN'			=> 'Deve ter entre %1$d e %2$d caracteres. Tem que incluir letras maiúsculas e minúsculas, números e símbolos.',
 	'PASSWORD'							=> 'Senha',
 	'PASSWORD_ACTIVATED'				=> 'A sua Nova Senha foi ativada.',
 	'PASSWORD_UPDATED'					=> 'Uma nova palavra passe foi enviada para o seu endereço registado de correio eletrónico.',
@@ -431,7 +434,7 @@ $lang = array_merge($lang, array(
 	'SEND_PASSWORD'						=> 'Enviar Senha',
 	'SENT_AT'							=> 'Enviado em',
 	'SHOW_EMAIL'						=> 'Tornar visível o meu endereço de email',
-	'SIGNATURE_EXPLAIN'					=> 'Escreva aqui a Assinatura que por defeito será adicionada a todas a Mensagens. O limite é de %d carateres.',
+	'SIGNATURE_EXPLAIN'					=> 'Escreva aqui a Assinatura que por defeito será adicionada a todas a Mensagens. O limite é de %d caracteres.',
 	'SIGNATURE_PREVIEW'					=> 'Previsão da Assinatura',
 	'SIGNATURE_TOO_LONG'				=> 'A sua Assinatura é muito grande.',
 	'SORT'								=> 'Ordenar',
@@ -506,12 +509,12 @@ $lang = array_merge($lang, array(
 	'UPLOAD_AVATAR_FILE'				=> 'Enviar do seu Computador',
 	'UPLOAD_AVATAR_URL'					=> 'Enviar de uma URL',
 	'UPLOAD_AVATAR_URL_EXPLAIN'			=> 'Insira a URL da imagem que pretende usar no Fórum.',
-	'USERNAME_ALPHA_ONLY_EXPLAIN'		=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d carateres e usar somente carateres alfanuméricos.',
-	'USERNAME_ALPHA_SPACERS_EXPLAIN'	=> 'O Nome de Utilizador ddeve ser constituído por %1$d a %2$d carateres e usar carateres alfanuméricos, espaço ou -+_[].',
-	'USERNAME_ASCII_EXPLAIN'			=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d carateres e deve conter somente carateres ASCII, sendo assim, sem símbolos especiais.',
-	'USERNAME_LETTER_NUM_EXPLAIN'		=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d carateres e deve conter somente letras ou números.',
-	'USERNAME_LETTER_NUM_SPACERS_EXPLAIN'	=> 'O Nome de utilizador deve ser constituído por %1$d a %2$d carateres e deve conter letras, números, espaço ou +-[].',
-	'USERNAME_CHARS_ANY_EXPLAIN'		=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d carateres.',
+	'USERNAME_ALPHA_ONLY_EXPLAIN'		=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d caracteres e usar somente caracteres alfanuméricos.',
+	'USERNAME_ALPHA_SPACERS_EXPLAIN'	=> 'O Nome de Utilizador ddeve ser constituído por %1$d a %2$d caracteres e usar caracteres alfanuméricos, espaço ou -+_[].',
+	'USERNAME_ASCII_EXPLAIN'			=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d caracteres e deve conter somente caracteres ASCII, sendo assim, sem símbolos especiais.',
+	'USERNAME_LETTER_NUM_EXPLAIN'		=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d caracteres e deve conter somente letras ou números.',
+	'USERNAME_LETTER_NUM_SPACERS_EXPLAIN'	=> 'O Nome de utilizador deve ser constituído por %1$d a %2$d caracteres e deve conter letras, números, espaço ou +-[].',
+	'USERNAME_CHARS_ANY_EXPLAIN'		=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d caracteres.',
 	'USERNAME_TAKEN_USERNAME'			=> 'O Nome de utilizador que escolheu já existe.',
 	'USERNAME_DISALLOWED_USERNAME'		=> 'O Nome de Utilizador que escolheu foi proibido ou contém uma palavra censurada. Escolha um nome diferente.',
 	'USER_NOT_FOUND_OR_INACTIVE'		=> 'O Nome de utilizador que escreveu não pode ser encontrado ou está inativo.',
